community/bluegriffon to 2.3.1-3

This commit is contained in:
Kevin Mihelich 2017-06-28 19:52:48 +00:00
parent c3c228dbb8
commit a9e2bf77e4
3 changed files with 59 additions and 1 deletions

View file

@ -11,7 +11,7 @@ highmem=1
pkgname=bluegriffon
pkgver=2.3.1
_mozilla_ver=f14898695ee0
pkgrel=2
pkgrel=3
pkgdesc="The next-generation Web Editor based on the rendering engine of Firefox"
arch=('i686' 'x86_64')
url="http://bluegriffon.org/"
@ -24,8 +24,11 @@ source=("${pkgname}-${pkgver}.tar.gz"::"https://github.com/therealglazou/${pkgna
"mozilla-central-${_mozilla_ver}.tar.bz2"::"https://hg.mozilla.org/mozilla-central/archive/${_mozilla_ver}.tar.bz2"
"bug_1329272_icu.patch"::"https://hg.mozilla.org/releases/mozilla-esr45/raw-diff/571b48abf054/build/autoconf/icu.m4"
"bug_1290037_update_keybits_in_h2.patch"::"https://hg.mozilla.org/mozilla-central/raw-rev/361ac226da2a"
"bug_1269171_mozalloc_in_stl_wrappers.patch"::"https://hg.mozilla.org/mozilla-central/raw-rev/68da139d0866"
"bug_1371991_no_lib_nss_crmf.patch"
"${pkgname}_gtk3.patch"
"bug_1234158_firefox-gtk3-20.patch"
"event__sizeof.patch"
"mozconfig"
"${pkgname}.desktop"
"bug_1257019.patch"::"https://hg.mozilla.org/mozilla-central/raw-rev/d5e77c8d64c9")
@ -33,8 +36,11 @@ sha256sums=('1fb0ba05a024be3029fe800ef0297e9e5ff3dcb631d04a95ca30e33e5aa261d7'
'0b13213b5f9b3819b56872f7fb4fa7a1170ade06f8797dc11114e5f7c8eabca2'
'93de8102de543bad38dc49d9ffcf7a8a2d9246594a8e7b92c38736ed6c6050cd'
'87fb92e45f161d47b9e3ca31bcce60555bc33d633116dab4baa3bfba6ad965c4'
'9d4849338dad39b978f7c15a93c3c255d72d7bfdffa897900a0bdddd771d2e17'
'08e40f75395d26359ce9bcce42789961900b4dc8fbab8555baba6a2895f7798d'
'3868f39181a258823c45e7ad62bba8e7b6e8b07c41535dd584c2dc71431f5deb'
'd5e1b9a702dc693184494899fc4cd57ac206e1fd5415a8e5520b8ff3b822e734'
'f4440c9d3826f4cda18b9d00129347fe6a22de61e11d593b1a522fa46d685ca0'
'3c162de2bae884a573b2c1260500352e6b9c7803758cc73975109482503b9eb0'
'882133b77840356985a81e496b4ddc443f8f33c068cfb7ef0858497820adcfff'
'd0229aa67aa68dd50755fd022cf34af2a2a36faef2cf2ce06a336ebef7a08974')
@ -53,6 +59,17 @@ prepare() {
# https://bugzilla.mozilla.org/show_bug.cgi?id=1290037
patch -Np1 -i "${srcdir}/bug_1290037_update_keybits_in_h2.patch"
# https://bugzilla.mozilla.org/show_bug.cgi?id=1269171
patch -Np1 -i "${srcdir}/bug_1269171_mozalloc_in_stl_wrappers.patch"
# https://bugzilla.mozilla.org/show_bug.cgi?id=1371991
# https://bugs.archlinux.org/task/54395
patch -Np1 -i "${srcdir}/bug_1371991_no_lib_nss_crmf.patch"
# Fix for libevent 2.1
# Change _EVENT_SIZEOF to EVENT__SIZEOF
patch -Np1 -i "${srcdir}/event__sizeof.patch"
# Move files to their correct location
cp -r "${srcdir}/${pkgname}-${pkgver}" bluegriffon
cp "${srcdir}/mozconfig" .mozconfig

View file

@ -0,0 +1,23 @@
diff -Naur mozilla-central-f14898695ee0.orig/config/external/nss/crmf/moz.build mozilla-central-f14898695ee0/config/external/nss/crmf/moz.build
--- mozilla-central-f14898695ee0.orig/config/external/nss/crmf/moz.build 2016-03-20 05:25:17.000000000 +0100
+++ mozilla-central-f14898695ee0/config/external/nss/crmf/moz.build 2017-06-11 21:50:40.989355686 +0200
@@ -8,7 +8,6 @@
if CONFIG['MOZ_SYSTEM_NSS']:
OS_LIBS += [l for l in CONFIG['NSS_LIBS'] if l.startswith('-L')]
- OS_LIBS += ['-lcrmf']
else:
USE_LIBS += [
# The dependency on nss is not real, but is required to force the
diff -Naur mozilla-central-f14898695ee0.orig/old-configure.in mozilla-central-f14898695ee0/old-configure.in
--- mozilla-central-f14898695ee0.orig/old-configure.in 2016-03-20 05:25:17.000000000 +0100
+++ mozilla-central-f14898695ee0/old-configure.in 2017-06-11 21:48:28.725284205 +0200
@@ -2601,7 +2601,7 @@
fi
if test -n "$MOZ_SYSTEM_NSS"; then
- NSS_LIBS="$NSS_LIBS -lcrmf"
+ NSS_LIBS="$NSS_LIBS"
else
NSS_CFLAGS="-I${DIST}/include/nss"
fi

View file

@ -0,0 +1,18 @@
diff -Naur mozilla-central-f14898695ee0.orig/ipc/chromium/src/base/message_pump_libevent.cc mozilla-central-f14898695ee0/ipc/chromium/src/base/message_pump_libevent.cc
--- mozilla-central-f14898695ee0.orig/ipc/chromium/src/base/message_pump_libevent.cc 2016-03-20 05:25:17.000000000 +0100
+++ mozilla-central-f14898695ee0/ipc/chromium/src/base/message_pump_libevent.cc 2017-06-11 19:44:51.294979917 +0200
@@ -18,11 +18,11 @@
#include "event.h"
#include "mozilla/UniquePtr.h"
// This macro checks that the _EVENT_SIZEOF_* constants defined in
// ipc/chromiume/src/third_party/<platform>/event2/event-config.h are correct.
#define CHECK_EVENT_SIZEOF(TYPE, type) \
- static_assert(_EVENT_SIZEOF_##TYPE == sizeof(type), \
- "bad _EVENT_SIZEOF_"#TYPE);
+ static_assert(EVENT__SIZEOF_##TYPE == sizeof(type), \
+ "bad EVENT__SIZEOF_"#TYPE);
CHECK_EVENT_SIZEOF(LONG, long);
CHECK_EVENT_SIZEOF(LONG_LONG, long long);
@@ -18,11 +18,11 @@
#include "event.h"
#include "mozilla/UniquePtr.h"
-// This macro checks that the _EVENT_SIZEOF_* constants defined in
+// This macro checks that the EVENT__SIZEOF_* constants defined in
// ipc/chromiume/src/third_party/<platform>/event2/event-config.h are correct.
#define CHECK_EVENT_SIZEOF(TYPE, type) \